@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2016-02-09'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-12-11'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,8 +13,8 @@ our @EXPORT_OK = qw(fatpack_modules);
 
 our %SPEC;
 
-my $mod_re    = qr/\A[A-Za-z_][A-Za-z0-9_]*(::[A-Za-z_][A-Za-z0-9_]*)*\z/;
-my $mod_pm_re = qr!\A[A-Za-z_][A-Za-z0-9_]*(/[A-Za-z_][A-Za-z0-9_]*)*\.pm\z!;
+my $mod_re    = qr/\A[A-Za-z_][A-Za-z0-9_]*(::[A-Za-z0-9_]+)*\z/;
+my $mod_pm_re = qr!\A[A-Za-z_][A-Za-z0-9_]*(/[A-Za-z0-9_]+)*\.pm\z!;
 
 $SPEC{fatpack_modules} = {
     v => 1.1,
@@ -35,6 +35,8 @@ _
     },
     args => {
         module_names => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'module_name',
             summary => 'Module names to search',
             schema  => ['array*', of=>['str*', match=>$mod_re], min_len=>1],
             tags => ['category:input'],
@@ -44,6 +46,8 @@ _
             cmdline_aliases => {m=>{}},
         },
         module_srcs => {
+            'x.name.is_plural' => 1,
+            'x.name.singular' => 'module_src',
             summary => 'Module source codes (a hash, keys are module names)',
             schema  => ['hash*', {
                 each_key=>['str*', match=>$mod_re],
@@ -218,7 +222,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.10 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-02-09.
+This document describes version 0.11 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-12-11.
 
 =head1 FUNCTIONS
 
